<?php

namespace Drupal\locationmap\Controller;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns a map.
 */
class LocationmapController extends ControllerBase {

  /**
   * Returns the config.factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $config;

  /**
   * Constructs a new LocationmapController.
   *
   * @param \Drupal\Core\Config\ConfigFactory $config
   *   Defines the configuration object factory.
   */
  public function __construct(ConfigFactory $config) {
    $this->config = $config;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * Get the page title.
   */
  public function title() {
    return $this->config->get('locationmap.settings')->get('title');
  }

  /**
   * Show a map.
   */
  public function map() {
    $config = $this->config->get('locationmap.settings');

    $build = [
      'body' => [
        '#markup' => '<div id="locationmap_body">' . $config->get('body') . '</div>',
      ],
      'map' => [
        '#theme' => 'locationmap_map',
        '#width' => $config->get('width') . 'px',
        '#height' => $config->get('height') . 'px',
        '#attached' => [
          'library' => [
            'locationmap/locationmap',
          ],
          'drupalSettings' => [
            'locationmap' => [
              'address' => $config->get('address'),
              'info' => $config->get('info'),
              'popinfo' => $config->get('popinfo'),
              'lat' => $config->get('lat'),
              'lng' => $config->get('lng'),
              'zoom' => $config->get('zoom'),
              'type' => $config->get('type'),
              'admin' => $this->currentUser()->hasPermission('administer locationmap'),
              'scroll' => $config->get('scroll'),
            ],
          ],
        ],
      ],
      'footer' => [
        '#markup' => '<div id="locationmap_footer">' . $config->get('footer') . '</div>',
      ],
    ];

    return $build;
  }

}
